/*******************************************************************************
 * Copyright (C) 2008
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 *
 * Author: Marko Reiprecht
 * Created: 18.07.2008
 * Modified: $Date $
 ******************************************************************************/
/* $Id: $ */
package org.n52.security.authentication;

import java.util.Date;
import javax.security.auth.Subject;
import javax.security.auth.login.LoginContext;

/**
 * Class JAASAuthenticationContext implements the AuthenticationContext interface.
 * Instances of this class are created by the JAASAuthenticationService.
 *
 * @author Marko Reiprecht
 *         Created on 18.07.2008
 * @version $Revision: $
 */
class JAASAuthenticationContext implements AuthenticationContext {

    private static final long serialVersionUID = -8589227863689927484L;

    private transient LoginContext m_loginContext;
    private Subject m_subject;
    private boolean m_authenticated;
    private Date m_authenticationTime;

    /**
     * Constructor creates a new instance.
     *
     * @param subject the subject.
     */
    protected JAASAuthenticationContext(final Subject subject) {
        m_subject = subject;
    }

    /**
     * Method gets the loginContext.
     *
     * @return LoginContext.
     */
    public LoginContext getLoginContext() {
        return m_loginContext;
    }

    /**
     * Method sets the loginContext.
     *
     * @param loginContext the loginContext.
     */
    public void setLoginContext(final LoginContext loginContext) {
        m_loginContext = loginContext;
    }

    /**
     * @see org.n52.security.authentication.AuthenticationContext#getSubject()
     */
    public Subject getSubject() {
        return m_subject;
    }

    /**
     * @see org.n52.security.authentication.AuthenticationContext#isAuthenticated()
     */
    public boolean isAuthenticated() {
        return m_authenticated;
    }

    /**
     * Method sets the authenticated.
     *
     * @param authenticated the authenticated.
     */
    public void setAuthenticated(final boolean authenticated) {
        m_authenticated = authenticated;
    }

    /**
     * @see org.n52.security.authentication.AuthenticationContext#getAuthenticationTime()
     */
    public Date getAuthenticationTime() {
        return m_authenticationTime;
    }

    /**
     * Method sets the authenticationTime.
     *
     * @param authenticationTime the authenticationTime.
     */
    public void setAuthenticationTime(final Date authenticationTime) {
        m_authenticationTime = authenticationTime;
    }
}
