/*******************************************************************************
 * Copyright (C) 2008
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.authentication;

import java.security.Principal;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Class LicensePrincipal is used to transport a license reference within the subject.
 * <p/>
 *
 * @author Marko Reiprecht
 *         Created on 05.03.2008
 * @version $Revision: $
 */
public class LicensePrincipal implements Principal {

    // ------------------------------ FIELDS ------------------------------

    /**
     * The Logger.
     */
    private static final Log LOG = LogFactory.getLog(LicensePrincipal.class);
    private LicenseReference m_licenseReference;

    // --------------------------- CONSTRUCTORS ---------------------------

    /**
     * Constructor creates a new instance.
     *
     * @param licref the licref.
     */
    public LicensePrincipal(
            final LicenseReference licref) {
        if (licref == null) {
            throw new NullPointerException("the license reference must not null");
        }
        m_licenseReference = licref;
    }

    // --------------------- GETTER / SETTER METHODS ---------------------

    /**
     * Method gets the transported license reference.
     *
     * @return LicenseReference.
     */
    public LicenseReference getLicenseReference() {
        return m_licenseReference;
    }

    /**
     * Returns the name of this principal.
     *
     * @return the name of this principal.
     */
    public String getName() {
        return m_licenseReference.referenceAsString();
    }

    // ------------------------ CANONICAL METHODS ------------------------

    /**
     * Method checks equality.
     *
     * @param o the o.
     * @return boolean.
     */
    public boolean equals(final Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof LicensePrincipal)) {
            return false;
        }

        final LicensePrincipal that = (LicensePrincipal) o;

        if (!m_licenseReference.equals(that.m_licenseReference)) {
            return false;
        }

        return true;
    }

    /**
     * creates a hashCode.
     *
     * @return int.
     */
    public int hashCode() {
        return m_licenseReference.hashCode();
    }
}