/*******************************************************************************
 * Copyright (C) 2008
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.common.util;

import java.util.HashMap;
import java.util.Map;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import org.apache.log4j.Logger;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.w3c.dom.Element;

/**
 * @deprecated replaced by the {@link org.n52.security.common.xml.DOMParser} class.
 */
public final class XMLUtils {

    private static Logger sLogger = Logger.getLogger(XMLUtils.class);

    private static DocumentBuilderFactory sLazyDocBuilderFac = DocumentBuilderFactory.newInstance();

    private static DocumentBuilderFactory sDocBuilderFac = DocumentBuilderFactory.newInstance();

    static {
        sLazyDocBuilderFac.setValidating(false);
        sLazyDocBuilderFac.setNamespaceAware(false);
        sLazyDocBuilderFac.setAttribute("http://apache.org/xml/features/nonvalidating/load-external-dtd",
                Boolean.FALSE);

        // sLazyDocBuilderFac.setFeature("http://xml.org/sax/features/validation", false);
        // sLazyDocBuilderFac.setFeature("http://apache.org/xml/features/nonvalidating/load-external-dtd",false);
    }

    /**
     *
     */
    private XMLUtils() {
    }

    /**
     * Delivers a namespace-unaware, non-validating DocumentBuilder.
     * 
     * @return the DocumentBuilder
     */
    public static DocumentBuilder getDocumentBuilder() {
        try {
            return sLazyDocBuilderFac.newDocumentBuilder();
        } catch (ParserConfigurationException e) {
            throw new RuntimeException(e);
        }
    }

    public static DocumentBuilder getDocumentBuilder(boolean pValidating, boolean pNamespaceAware) {
        try {
            sDocBuilderFac.setValidating(pValidating);
            sDocBuilderFac.setNamespaceAware(pNamespaceAware);
            sDocBuilderFac.setAttribute("http://apache.org/xml/features/nonvalidating/load-external-dtd",
                    Boolean.FALSE);
            return sDocBuilderFac.newDocumentBuilder();
        } catch (ParserConfigurationException e) {
            throw new RuntimeException(e);
        }
    }

    public static Map getParameters(NodeList pParameter) {
        Map lReturnMap = new HashMap();
        for (int i = 0, len = pParameter.getLength(); i < len; i++) {
            Element tCurrentNode = (Element) pParameter.item(i);
            String tParamName = tCurrentNode.getAttributes().getNamedItem("name").getNodeValue().trim();

            String tParamValue = getText(tCurrentNode);
            lReturnMap.put(tParamName, tParamValue);
        }
        return lReturnMap;
    }

    /**
     * Method gets the text from this element.
     * 
     * @param attributevalue
     *            the attributevalue.
     * @return String.
     */
    private static String getText(final Element attributevalue) {
        NodeList childs = attributevalue.getChildNodes();
        for (int i = 0, l = childs.getLength(); i < l; ++i) {
            Node child = childs.item(i);
            if (Node.TEXT_NODE == child.getNodeType()) {
                return child.getNodeValue().trim();
            }
        }
        return null;
    }

}
