/*******************************************************************************
 * Copyright (C) 2008
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 *
 * Author: Marko Reiprecht
 * Created: 18.04.2008
 ******************************************************************************/
package org.n52.security.common.xml;

import javax.xml.namespace.QName;

/**
 * Class XMLPartialStreamHandlerAdapter implements the XMLPartialStreamHandler interface,
 * with empty method stubs, so that subclasses only need to implement methods in which they are interested.
 * <p/>
 * It declares a helper method, which closes the open xml chunk within the *Befor/AfterChild* methods.
 *
 * @author Marko Reiprecht
 *         Created on 18.04.2008
 * @version $Revision: $
 */
public abstract class XMLChunkHandlerAdapter implements XMLChunkHandler {

    /**
     * Method appends the endtag to a open xml chunk.
     *
     * @param xmlChunk   the partialXml.
     * @param endElement the endElement.
     * @return String.
     */
    protected String closePartialXml(final String xmlChunk, final QName endElement) {
        StringBuffer buffer = new StringBuffer(xmlChunk).append("</");
        if (endElement.getPrefix() != null && endElement.getPrefix().length() > 0) {
            buffer.append(endElement.getPrefix()).append(":");
        }
        buffer.append(endElement.getLocalPart())
                .append(">");
        return buffer.toString();
    }

    /**
     * @see XMLChunkHandler#handleChunkStart(QName)
     */
    public void handleChunkStart(final QName handlerQName) {
    }

    /**
     * @see XMLChunkHandler#handleChunkEnd(QName, String)
     */
    public void handleChunkEnd(final QName handlerQName, final String xmlChunk) {

    }

    /**
     * @see XMLChunkHandler#handleChunkBeforChildHandler(QName, String, QName, XMLChunkHandler)
     */
    public void handleChunkBeforChildHandler(final QName handlerQName, final String xmlChunk,
                                             final QName childQName, final XMLChunkHandler childHandler) {
    }

    /**
     * @see XMLChunkHandler#handleChunkAfterChildHandler(QName, String, QName, XMLChunkHandler)
     */
    public void handleChunkAfterChildHandler(final QName handlerQName, final String xmlChunk,
                                             final QName childQName, final XMLChunkHandler childHandler) {
    }
}
