/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 * 
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 * 
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.decision;

import java.io.Serializable;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;


/**
 * This class encapsulates PDPResponse.
 * All Response for PDPRequests in one PDPRequestCollection should be collected in one PDPResponseCollection.
 *
 * @author Bastian Schaeffer
 * @author Marko Reiprecht
 * @version $Revision: 1748 $
 */
public class PDPResponseCollection implements Serializable {

    // ------------------------------ FIELDS ------------------------------

    private static final long serialVersionUID = -984031222845338234L;

    /**
     * List of {@link PDPResponse} instances.
     */
    protected List m_responses = new LinkedList();

    // --------------------------- CONSTRUCTORS ---------------------------

    /**
     * Constructor creates a new instance.
     */
    public PDPResponseCollection() {}

    /**
     * Constructor creates a new instance.
     *
     * @param pdpResponse the pdpResponse.
     */
    public PDPResponseCollection(final PDPResponse pdpResponse) {
        this.add(pdpResponse);
    }

    /**
     * Method adds a response.
     *
     * @param response the response.
     * @return PDPResponseCollection.
     */
    public PDPResponseCollection add(final PDPResponse response) {
        m_responses.add(response);
        return this;
    }

    // ------------------------ CANONICAL METHODS ------------------------

    /**
     * Method equals.
     *
     * @param o the o.
     * @return boolean.
     */
    public boolean equals(final Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }

        final PDPResponseCollection that = (PDPResponseCollection) o;

        if (!m_responses.equals(that.m_responses)) {
            return false;
        }

        return true;
    }

    /**
     * Method hashCode.
     *
     * @return int.
     */
    public int hashCode() {
        return m_responses.hashCode();
    }

    /**
     * Method toString.
     *
     * @return String.
     */
    public String toString() {
        final StringBuffer sb = new StringBuffer();
        sb.append("org.n52.security.decision.PDPResponseCollection");
        sb.append("{m_responses=").append(m_responses);
        sb.append('}');
        return sb.toString();
    }

    // -------------------------- OTHER METHODS --------------------------

    /**
     * Method iterator.
     *
     * @return Iterator.
     */
    public Iterator iterator() {
        return m_responses.iterator();
    }

    /**
     * Method remove.
     *
     * @param response the response.
     * @return this.
     */
    public PDPResponseCollection remove(final PDPResponse response) {
        m_responses.remove(response);
        return this;
    }

    /**
     * Method size.
     *
     * @return int.
     */
    public int size() {
        return m_responses.size();
    }

    /**
     * Method isEmpty.
     *
     * @return int.
     */
    public boolean isEmpty() {
        return m_responses.isEmpty();
    }
}