/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 * 
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 * 
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.enforcement.artifact;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.UnsupportedEncodingException;

import org.apache.log4j.Logger;

/**
 * @author <a href="mailto:broering@52north.org">Arne Broering</a>
 */
public class StreamPayload implements Payload {
    private static final Logger LOG = Logger.getLogger(TextualPayload.class);

    /**
     * The bytes as provided by the client.
     */
    protected byte[] m_originalBytes;

    /**
     * Character set used when the bytes are converted to character data.
     */
    protected String m_charset;

    /**
     * Creates a new StreamPayload.
     * 
     */
    public StreamPayload(final InputStream pIn, final String pCharset) throws IOException {
        m_charset = pCharset;
        m_originalBytes = copyStream(pIn);
    }

    private byte[] copyStream(final InputStream pIn) throws IOException {
        ByteArrayOutputStream lOutputStream = new ByteArrayOutputStream();

        byte[] lBuffer = new byte[128];
        int lLen = -1;

        while ((lLen = pIn.read(lBuffer)) != -1) {
            lOutputStream.write(lBuffer, 0, lLen);
        }

        return lOutputStream.toByteArray();
    }

    public InputStream getAsStream() {
        return new ByteArrayInputStream(m_originalBytes);
    }

    public String toString() {
        try {
            if (m_charset != null) {
                return new String(m_originalBytes, m_charset);
            } else {
                return new String(m_originalBytes, "UTF-8"); // use UTF-8 as default!!
            }
        } catch (UnsupportedEncodingException e) {
            LOG.error("Fehler !!!", e);
            return new String(m_originalBytes);
        }
    }

    public byte[] toByteArray() {
        return m_originalBytes;
    }

    public TextualPayload toTextualPayload() {
        try {
            return new TextualPayload(getAsStream(), m_charset);
        } catch (IOException e) {
            LOG.error("Fehler !!!", e);
            return new TextualPayload(toString(), m_charset);
        }
    }
}
