/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 * 
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 * 
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.enforcement.artifact;

import org.apache.log4j.Logger;

import java.io.IOException;
import java.io.InputStream;

/**
 * 
 * @author JanDrewnak
 * 
 */
public class TransferableFactory {

    private static final Logger LOG = Logger.getLogger(TransferableFactory.class);

    private static TransferableFactory mInstance = new TransferableFactory();

    private TransferableFactory() {
    }

    public static TransferableFactory getInstance() {
        return mInstance;
    }

    public Transferable createTextualTransferable(final String pContentType, final String pPayLoad,
            final String pTargetCharset) {
        Transferable lTransferable = new TransferableImpl();
        lTransferable.setPayload(new TextualPayload(pPayLoad, pTargetCharset));
        if (pContentType != null) {
            lTransferable.addAttribute(HttpHeaderAttribute.createHttpHeaderAttribute(
                    HttpHeaderAttribute.HEADER_NAME_CONTENTTYPE, pContentType));
        }
        if (pTargetCharset != null) {
            lTransferable.addAttribute(HttpHeaderAttribute.createHttpHeaderAttribute(
                    HttpHeaderAttribute.HEADER_NAME_CONTENTENCODING, pTargetCharset));
        }
        return lTransferable;
    }

    public Transferable createStreamTransferable(final String pContentType, final InputStream pPayLoad,
            final String pCharset) throws IOException {
        Transferable lTransferable = new TransferableImpl();
        lTransferable.setPayload(new StreamPayload(pPayLoad, pCharset));
        if (pContentType != null) {
            lTransferable.addAttribute(HttpHeaderAttribute.createHttpHeaderAttribute(
                    HttpHeaderAttribute.HEADER_NAME_CONTENTTYPE, pContentType));
        }
        if (pCharset != null) {
            lTransferable.addAttribute(HttpHeaderAttribute.createHttpHeaderAttribute(
                    HttpHeaderAttribute.HEADER_NAME_CONTENTENCODING, pCharset));
        }
        return lTransferable;
    }
}