/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 * 
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 * 
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.enforcement.artifact;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

/**
 * Default implementation of {@link Transferable}.
 */
public class TransferableImpl implements Transferable {

    /**
     * Payload tranferred by this Transferable.
     */
    protected Payload m_payload;

    /**
     * Attributes associated with this instnace.
     */
    protected Map m_attributes = new HashMap(5);

    public Payload getPayload() {
        return m_payload;
    }

    public void setPayload(final Payload pPayload) {
        m_payload = pPayload;
    }

    public Collection getAttributeNames() {
        Collection attrNames = new ArrayList(m_attributes.size());
        // Create list of attribute names with original upper/lower case writing.
        for (Iterator iterator = m_attributes.values().iterator(); iterator.hasNext();) {
            TransferAttribute attr = (TransferAttribute) iterator.next();
            attrNames.add(attr.getName());
        }
        return attrNames;
    }

    public Collection getAttributes() {
        return m_attributes.values();
    }

    public TransferAttribute getAttribute(final String pName) {
        return (TransferAttribute) m_attributes.get(pName.toLowerCase());
    }

    public Object getAttributeValue(final String pName) {
        TransferAttribute lRes = getAttribute(pName.toLowerCase());
        return lRes != null ? lRes.getValue() : null;
    }

    public void addAttribute(final TransferAttribute pAttribute) {
        if (pAttribute != null) {
            m_attributes.put(pAttribute.getName().toLowerCase(), pAttribute);
        }
    }
}