/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 * 
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 * 
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.precondition;

import java.util.List;
import java.util.NoSuchElementException;
import java.util.Vector;

import org.apache.log4j.Logger;

/**
 * This class manages multiple preconditions and provides acces to them.
 * 
 * @author Oliver Meyer
 * @version 0.1
 */
public class PreconditionManager {

    private static final Logger LOGGER = Logger.getLogger(PreconditionManager.class);

    private Vector m_preconditionList = null;

    private Precondition m_actualPrecondition = null;

    /**
     * Creates a new instance with an empty list.
     *
     */
    public PreconditionManager() {

        m_preconditionList = new Vector();

        LOGGER.debug("new PreconditionManager instace with empty precondition list created");

    }

    /**
     * Creates a new instance and sets the list containing the preconditions.
     * @param preconditionList list containig the preconditions
     */
    public PreconditionManager(final List preconditionList) {

        m_preconditionList = new Vector(preconditionList);

        LOGGER.debug("new PreconditionManager instance created");

    }

    /**
     * Sets list containing tje preconditions.
     * @param preconditionList list containing the preconditions
     */
    public void setPreconditions(final List preconditionList) {

        m_preconditionList = new Vector(preconditionList);

    }

    /**
     * Returns the precondition count.
     * @return precondition count
     */
    public int getPreconditionsCount() {

        return m_preconditionList.size();

    }

    /**
     * Removes processed precondition.
     * 
     */
    public void preconditionProcessed() {

        m_preconditionList.remove(m_actualPrecondition);

    }

    /**
     * Checks if there are unprocessed preconditions left.
     * @return true if there are unprocessed preconditions, else false
     */
    public boolean hasUnprocessedPreconditions() {

        return !m_preconditionList.isEmpty();

    }

    /**
     * Returns next unprocessed precondition.
     * 
     * @return next unprocessed precondition
     * @throws NoSuchElementException
     *             is thrown in case list is empty (check with
     *             {@link <#hasUnprocessedPreconditions()> hasUnprocessedPreconditions}before
     *             calling this method)
     */
    public Precondition getNextUnprocessedPrecondition() throws NoSuchElementException {

        m_actualPrecondition = (Precondition) m_preconditionList.firstElement();

        return m_actualPrecondition;

    }

}